@@ -108,7 +108,6 @@ class BaseInteraction:
             self.channel = None
 
         self._sent = False
-        self._webhook = None
 
     @property
     def created_at(self):
@@ -130,15 +129,9 @@ class BaseInteraction:
     def client(self):
         return self.bot
 
-    def _cache_ephemeral_message(self, message):
-        try:
-            cached = self.bot.cached_ephemeral_messages
-        except AttributeError:
-            self.bot.cached_ephemeral_messages = []
-            cached = self.bot.cached_ephemeral_messages
-        cached.append(message)
-        if len(cached) > 1000:
-            cached.pop(0)
+    @property
+    def me(self):
+        return self.guild.me if self.guild is not None else self.bot.user
 
     async def reply(self, content=None, *,  embed=None, embeds=None,
                     components=None, view=None,
@@ -245,11 +238,6 @@ class BaseInteraction:
             self.bot.loop.create_task(self.delete_after(delete_after))
 
         if fetch_response_message:
-            if ephemeral:
-                msg = await self.edit(content=content, embed=embed, embeds=embeds)
-                msg._overwrite_components(components)
-                self._cache_ephemeral_message(msg)
-                return msg
             try:
                 return await self.fetch_initial_response()
             except Exception:
@@ -296,7 +284,7 @@ class BaseInteraction:
         data = {}
         if content is not None:
             data['content'] = str(content)
-        # Embed or embeds
+        
         if embed is not None and embeds is not None:
             raise discord.InvalidArgument("Can't pass both embed and embeds")
 
@@ -312,7 +300,7 @@ class BaseInteraction:
                 raise discord.InvalidArgument('embeds parameter must be a list of discord.Embed')
             data['embeds'] = [embed.to_dict() for embed in embeds]
 
-        if view:
+        if view is not None:
             if not hasattr(view, '__discord_ui_view__'):
                 raise discord.InvalidArgument(f'view parameter must be View not {view.__class__!r}')
 
@@ -320,7 +308,7 @@ class BaseInteraction:
         else:
             _components = None
 
-        if components:
+        if components is not None:
             if len(components) > 5:
                 raise discord.InvalidArgument("components must be a list of up to 5 action rows")
             _components = _components or []
@@ -330,10 +318,9 @@ class BaseInteraction:
                 else:
                     _components.append(ActionRow(comp).to_dict())
 
-        if _components:
+        if _components is not None:
             data["components"] = _components
 
-        # Allowed mentions
         if content or embed or embeds:
             state = self.bot._connection
             if allowed_mentions is not None:
@@ -342,22 +329,22 @@ class BaseInteraction:
                 else:
                     allowed_mentions = allowed_mentions.to_dict()
                 data['allowed_mentions'] = allowed_mentions
-        # Message design
+        
         if ephemeral:
             data["flags"] = 64
         if tts:
             data["tts"] = True
-        # Final JSON formation
-        _json = {"type": type}
+        
+        payload = {"type": type}
         if data:
-            _json["data"] = data
-        # HTTP-request
+            payload["data"] = data
+        
         await self.bot.http.request(
             Route(
                 'POST', '/interactions/{interaction_id}/{token}/callback',
                 interaction_id=self.id, token=self.token
             ),
-            json=_json
+            json=payload
         )
 
     async def edit(self, content=None, *, embed=None, embeds=None, components=None, allowed_mentions=None):
